package cn.com.infosec.asn1.ocsp;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREnumerated;
import cn.com.infosec.asn1.DERGeneralizedTime;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.CRLReason;

public class RevokedInfo extends ASN1Encodable {
   private DERGeneralizedTime revocationTime;
   private CRLReason revocationReason;

   public RevokedInfo(DERGeneralizedTime revocationTime, CRLReason revocationReason) {
      this.revocationTime = revocationTime;
      this.revocationReason = revocationReason;
   }

   public RevokedInfo(ASN1Sequence seq) {
      this.revocationTime = (DERGeneralizedTime)seq.getObjectAt(0);
      if (seq.size() > 1) {
         this.revocationReason = new CRLReason(DEREnumerated.getInstance((ASN1TaggedObject)seq.getObjectAt(1), true));
      }

   }

   public static RevokedInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static RevokedInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof RevokedInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new RevokedInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
         }
      } else {
         return (RevokedInfo)obj;
      }
   }

   public DERGeneralizedTime getRevocationTime() {
      return this.revocationTime;
   }

   public CRLReason getRevocationReason() {
      return this.revocationReason;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.revocationTime);
      CRLReason var3;
      if ((var3 = this.revocationReason) != null) {
         DERTaggedObject var2;
         var2 = new DERTaggedObject.<init>(true, 0, var3);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
